==> aws-cdk.aws-mediaconvert-1.132.0.tar.gz: package/lib/mediaconvert-canned-metrics.generated.d.ts <==
export declare class MediaConvertMetrics {
    static transcodingTimeAverage(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            Queue: string;
        };
        statistic: string;
    };
    static jobsCompletedCountSum(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            Queue: string;
        };
        statistic: string;
    };
    static _8KOutputDurationAverage(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            Queue: string;
        };
        statistic: string;
    };
    static audioOutputDurationAverage(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            Queue: string;
        };
        statistic: string;
    };
    static hdOutputDurationAverage(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            Queue: string;
        };
        statistic: string;
    };
    static jobsErroredCountSum(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            Queue: string;
        };
        statistic: string;
    };
    static sdOutputDurationAverage(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            Queue: string;
        };
        statistic: string;
    };
    static standbyTimeSum(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            Queue: string;
        };
        statistic: string;
    };
    static uhdOutputDurationAverage(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            Queue: string;
        };
        statistic: string;
    };
}

==> aws-cdk.aws-mediaconvert-1.156.1.tar.gz: package/lib/mediaconvert-canned-metrics.generated.d.ts <==
export declare class MediaConvertMetrics {
    static transcodingTimeAverage(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            Queue: string;
        };
        statistic: string;
    };
    static jobsCompletedCountSum(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            Queue: string;
        };
        statistic: string;
    };
    static _8KOutputDurationAverage(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            Queue: string;
        };
        statistic: string;
    };
    static audioOutputDurationAverage(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            Queue: string;
        };
        statistic: string;
    };
    static hdOutputDurationAverage(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            Queue: string;
        };
        statistic: string;
    };
    static jobsErroredCountSum(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            Queue: string;
        };
        statistic: string;
    };
    static sdOutputDurationAverage(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            Queue: string;
        };
        statistic: string;
    };
    static standbyTimeSum(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            Queue: string;
        };
        statistic: string;
    };
    static uhdOutputDurationAverage(dimensions: {
        Queue: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            Queue: string;
        };
        statistic: string;
    };
}
